@@ -324,6 +324,7 @@ from .._impl import (
     scout_compute_api_TimestampConstantVisitor as TimestampConstantVisitor,
     scout_compute_api_UnaryArithmeticOperation as UnaryArithmeticOperation,
     scout_compute_api_UnaryArithmeticSeries as UnaryArithmeticSeries,
+    scout_compute_api_UnboundedBehavior as UnboundedBehavior,
     scout_compute_api_UnionRanges as UnionRanges,
     scout_compute_api_UnitComputationError as UnitComputationError,
     scout_compute_api_UnitComputationErrorVisitor as UnitComputationErrorVisitor,
@@ -665,6 +666,7 @@ __all__ = [
     'TimestampConstantVisitor',
     'UnaryArithmeticOperation',
     'UnaryArithmeticSeries',
+    'UnboundedBehavior',
     'UnionRanges',
     'UnitComputationError',
     'UnitComputationErrorVisitor',
